==> com.liferay.frontend.editor.ckeditor.web-4.0.24.jar: META-INF/resources/editor/InlineEditor.js <==
Liferay.Loader.define("frontend-editor-ckeditor-web@4.0.24/editor/InlineEditor", ['module', 'exports', 'require', 'frontend-editor-ckeditor-web$ckeditor4-react', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.InlineEditor = void 0;

    var _ckeditor4React = _interopRequireDefault(require("frontend-editor-ckeditor-web$ckeditor4-react"));

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _extends() {
      _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
          var source = arguments[i];for (var key in source) {
            if (Object.prototype.hasOwnProperty.call(source, key)) {
              target[key] = source[key];
            }
          }
        }return target;
      };return _extends.apply(this, arguments);
    }

    var BASEPATH = '/o/frontend-editor-ckeditor-web/ckeditor/';

    var InlineEditor = function InlineEditor(props) {
      return _react["default"].createElement(_ckeditor4React["default"], _extends({}, props, {
        type: "inline"
      }));
    };

    exports.InlineEditor = InlineEditor;
    _ckeditor4React["default"].editorUrl = "".concat(BASEPATH, "ckeditor.js");
    window.CKEDITOR_BASEPATH = BASEPATH;
    //# sourceMappingURL=InlineEditor.js.map
  }
});
//# sourceMappingURL=InlineEditor.js.map

==> com.liferay.frontend.editor.ckeditor.web-4.0.27.jar: META-INF/resources/editor/InlineEditor.js <==
Liferay.Loader.define("frontend-editor-ckeditor-web@4.0.27/editor/InlineEditor", ['module', 'exports', 'require', 'frontend-editor-ckeditor-web$ckeditor4-react', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.InlineEditor = void 0;

    var _ckeditor4React = _interopRequireDefault(require("frontend-editor-ckeditor-web$ckeditor4-react"));

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _extends() {
      _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
          var source = arguments[i];for (var key in source) {
            if (Object.prototype.hasOwnProperty.call(source, key)) {
              target[key] = source[key];
            }
          }
        }return target;
      };return _extends.apply(this, arguments);
    }

    var BASEPATH = '/o/frontend-editor-ckeditor-web/ckeditor/';

    var InlineEditor = function InlineEditor(props) {
      return (/*#__PURE__*/_react.default.createElement(_ckeditor4React.default, _extends({}, props, {
          type: "inline"
        }))
      );
    };

    exports.InlineEditor = InlineEditor;
    _ckeditor4React.default.editorUrl = "".concat(BASEPATH, "ckeditor.js");
    window.CKEDITOR_BASEPATH = BASEPATH;
    //# sourceMappingURL=InlineEditor.js.map
  }
});
//# sourceMappingURL=InlineEditor.js.map
